/***************************************************************************
 *
 * $Header: /usr/local/cvsroot/utils/ytree/quit.c,v 1.12 2000/07/13 18:26:06 werner Exp $
 *
 * Verlassen von ytree
 *
 * 
 ***************************************************************************/


#include "ytree.h"





void Quit(void)
{
  int term;
  char path[PATH_LENGTH + 1];
  char *p;

  term = InputChoise( "quit ytree (Y/N) ?", "YNQq\r\033" );

  if( term == 'Y' || term == 'Q' || term == 'q' )
  {
    if (( p = getenv("HOME") ))
    {
      sprintf(path, "%s%c%s", p, FILE_SEPARATOR_CHAR, HISTORY_FILENAME);
      SaveHistory(path);
    }
    endwin();
#ifdef XCURSES
    XCursesExit();
#endif
    exit( 0 );
  }
}


